* ------------------------------------------------------------------------------

* CIS - Community Innovation Survey, wave 4 - Data without Boundaries

* This setup file converts the raw ITALY data from CSV to Stata
* Checked for the July 2013 release of the CIS, as provided by Eurostat

* Version 2 of the file, January 2015
* Tested with Stata/IC 12.0 for Mac (64-bit Intel)

* University of Bucharest, Romanian Social Data Archive
* Adrian Dusa
* http://www.roda.ro
* Contact: dusa.adrian@unibuc.ro

* ------------------------------------------------------------------------------



/* Initialization commands */
clear
capture log close
set more off
version 12.0
set linesize 250
set varabbrev off
set memory 1G // not necessary in Stata 12
#delimit ;


* ---------------------------------------------------------------------------- ;

* --- CONFIGURATION SECTION - START ---                                        ;

* The following command should contain the complete path and                   ;
* name of the Stata log file.                                                  ;
* Change LOG_FILENAME to your filename, below:                                 ;
local log_file "LOG_FILENAME" ;


* The following command should contain the complete path and                   ;
* name of the CSV file, usual file extension ".csv"                            ;
* Change CSV_DATA_PATH to your filename, below:                                ;
local csvpath "CSV_DATA_PATH" ;


* The following command should contain the complete path and                   ;
* name of the STATA file, usual file extension ".dta"                          ;
* Change STATA_DATA_PATH to your filename, below:                              ;
local statapath "STATA_DATA_PATH" ;


* --- CONFIGURATION SECTION - END ---                                          ;

* ---------------------------------------------------------------------------- ;



* There should be nothing to change below this line                            ;
* ---------------------------------------------------------------------------- ;



log using "`log_file'", replace text ;

insheet using "`csvpath'", comma names case ;

* Note that some variables in the csv raw data file might be in lowercase      ;
* To ensure that the dataset contains only variable names in uppercase         ;

foreach var of varlist _all { ;
    local newname = upper("`var'") ;
    cap rename `var' `newname' ;
} ;


* Rename country specific variables ;

drop WEIGHT ;

rename HO C_HO ;
rename RTOT RTOT_MSK ;
rename RRDINX RRDINXM ;
rename RRDEXX RRDEXXM ;
rename RMACX RMACXM ;
rename ROEKX ROEKXM ;
rename RTRX RTRXM ;
rename RPREX RPREXM ;
rename RMARX RMARXM ;
rename TURN02 TURN02M ;
rename TURN04 TURN04M ;
rename EMP04 SIZE02 ;
rename EMP02 SIZE04 ;
rename WEIGHTNR WEIGHT ;
rename NACE NACE_PRO ;
rename NUTS COUNTRY ;
rename NEWFFRM NEWFRM ;


* Recode string variables which have labels, to numeric variables ;

recode NACE_PRO
(10 = 1) (15 = 2) (17 = 3) (18 = 3) (19 = 4) (20 = 5) (21 = 5) (22 = 6) (23 = 7)
(24 = 7)(25 = 8) (26 = 9) (27 = 10) (28 = 11) (29 = 12) (30 = 13) (31 = 13)
(32 = 13) (33 = 13) (34 = 14) (35 = 14) (36 = 15) (37 = 15) (40 = 16) (45 = 17)
(50 = 18) (51 = 19) (52 = 20) (55 = 21) (60 = 22) (61 = 22) (62 = 22) (63 = 23)
(64 = 24) (65 = 25) (66 = 25) (67 = 25) (70 = 26) (71 = 27) (72 = 28) (73 = 29)
(74 = 29) (742 = 29) (743 = 29) ;

generate TEMPVAR = . ;
replace TEMPVAR = 0 if C_HO == "0" ;
replace TEMPVAR = 1 if C_HO == "1" ;
replace TEMPVAR = 2 if C_HO == "2" ;
replace TEMPVAR = 3 if C_HO == "3" ;
replace TEMPVAR = 4 if C_HO == "NN" ;
drop C_HO ;
rename TEMPVAR C_HO;

generate TEMPVAR = . ;
replace TEMPVAR = 1 if PMOS == "A" ;
replace TEMPVAR = 2 if PMOS == "B" ;
replace TEMPVAR = 3 if PMOS == "C" ;
replace TEMPVAR = 4 if PMOS == "D" ;
replace TEMPVAR = 5 if PMOS == "E" ;
replace TEMPVAR = 6 if PMOS == "F" ;
replace TEMPVAR = 7 if PMOS == "G" ;
drop PMOS ;
rename TEMPVAR PMOS ;

recode SIZE02
(1 = 0) (2 = 1) (3 = 2) (5 = 3) (6 = 4) ;

recode SIZE02
(1 = 0) (2 = 1) (3 = 2) (5 = 3) (6 = 4) ;



* Rename country specific variables ;

drop WEIGHT ;

rename RTOT RTOT_MSK ;
rename RRDINX RRDINXM ;
rename RRDEXX RRDEXXM ;
rename RMACX RMACXM ;
rename ROEKX ROEKXM ;
rename RTRX RTRXM ;
rename RPREX RPREXM ;
rename RMARX RMARXM ;
rename TURN02 TURN02M ;
rename TURN04 TURN04M ;
rename EMP04 SIZE02 ;
rename EMP02 SIZE04 ;
rename WEIGHTNR WEIGHT ;
rename NACE NACE_PRO ;
rename NUTS COUNTRY ;
rename NEWFFRM NEWFRM ;


* Definition of variable labels ;

label variable COUNTRY  "Country" ;
label variable NACE_PRO "Main activity" ;
label variable C_HO     "Country of head office" ;
label variable RRDINXM  "Expenditure in intramural R&D" ;
label variable RRDEXXM  "Expenditure in extramural R&D" ;
label variable RMACXM   "Expenditure in acquisition of machinery" ;
label variable ROEKXM   "Expenditure in other external knowledge" ;
label variable RTRXM    "Expenditure in training" ;
label variable RPREXM   "Expenditure in other preparation" ;
label variable RMARXM   "Expenditure in market introduction of innovation" ;
label variable RTOT_MSK "Total for four expenditure categories" ;
label variable TURN02M  "Total turnover in 2002" ;
label variable TURN04M  "Total turnover in 2004" ;
label variable SIZE02   "Total number of employees in 2002" ;
label variable SIZE04   "Total number of employees in 2004" ;
label variable WEIGHT   "Weighting factors" ;
label variable GP       "Enterprise part of a group" ;
label variable ID       "Name of enterprise" ;
label variable MARLOC   "Local/regional market" ;
label variable MARNAT   "National I market" ;
label variable MAREUR   "Other EU/EFTA/CC market" ;
label variable MAROTH   "All other countries" ;
label variable INPDGD   "Introduced onto the market a new or significantly improved good" ;
label variable INPDSV   "Introduced onto the market a new or significantly improved service" ;
label variable INPDTW   "Who mainly developed these products" ;
label variable NEWMKT   "Did the enterprise introduce a product new to the market" ;
label variable TURNMAR  "% of turnover in new or improved products introduced during 2002-2004 that were new to the market" ;
label variable TURNIN   "% of turnover in unchanged or marginally modified products during  2002-2004 that were new to the firm" ;
label variable TURNUNG  "% of turnover in unchanged or marginally modified products during 2002-2004" ;
label variable INPSPD   "Introduced onto the market a new or significantly improved method of production" ;
label variable INPSLG   "Introduced onto the market a new or significantly improved logistic, delivery or distribution system" ;
label variable INPSSU   "Introduced onto the market a new or significantly improved supporting activities" ;
label variable INPCSW   "Who mainly developed these processes" ;
label variable INONAB   "Enterprise with ongoing or abandoned innovation activities" ;
label variable RRDIN    "Engagement in intramural R&D" ;
label variable RDENG    "Type of engagement in R&D" ;
label variable RRDEX    "Engagement in extramural R&D" ;
label variable RMAC     "Engagement in acquisition of machinery" ;
label variable ROEK     "Engagement in other external knowledge" ;
label variable RTR      "Engagement in training" ;
label variable RMAR     "Engagement in market introduction of innovation" ;
label variable RPRE     "Engagement in other preparation" ;
label variable FUNLOC   "Public funding from local ro regional authorities" ;
label variable FUNGMT   "Public funding from central government" ;
label variable FUNEU    "Public funding from the EU" ;
label variable FUNRTD   "Funding from EU's 5th of 6th RTD" ;
label variable SENTG    "Sources from within the enterprise or enterprise group" ;
label variable SSUP     "Sources from Suppliers of equipment, materials, etc" ;
label variable SCLI     "Sources from Clients or customers" ;
label variable SCOM     "Sources from Competitors and other enterprises of same industry" ;
label variable SINS     "Sources from consultants, commercial labs or private R&D institutes" ;
label variable SUNI     "Sources from Universities or other higher education institutes" ;
label variable SGMT     "Sources from Government or public research institutes" ;
label variable SCON     "Sources from professional conferences, trade fairs, meetings" ;
label variable SJOU     "Sources from Scientific journals, trade/scientific publications" ;
label variable SPRO     "Sources from Professional and industry associations" ;
label variable CO       "Cooperation arrangements on innovation activities" ;
label variable CO11     "Other enterprises within enterprise group:National" ;
label variable CO12     "Other enterprises within enterprise group:EU/EFTA/EU-CC" ;
label variable CO13     "Other enterprises within enterprise group:US" ;
label variable CO14     "Other enterprises within enterprise group:Other countries" ;
label variable CO21     "Suppliers of equipment, etc:National" ;
label variable CO22     "Suppliers of equipment, etc:EU/EFTA/EU-CC" ;
label variable CO23     "Suppliers of equipment, etc:US" ;
label variable CO24     "Suppliers of equipment, etc:Other countries" ;
label variable CO31     "Clients or customers:National" ;
label variable CO32     "Clients or customers:EU/EFTA/EU-CC" ;
label variable CO33     "Clients or customers:US" ;
label variable CO34     "Clients or customers:Other countries" ;
label variable CO41     "Competitors or other firms ...:National" ;
label variable CO42     "Competitors or other firms ...:EU/EFTA/EU-CC" ;
label variable CO43     "Competitors or other firms ...:US" ;
label variable CO44     "Competitors or other firms ...:Other countries" ;
label variable CO51     "Consultants, commercial labs, private R&D institutes:National" ;
label variable CO52     "Consultants, commercial labs, private R&D institutes:EU/EFTA/EU-CC" ;
label variable CO53     "Consultants, commercial labs, private R&D institutes:US" ;
label variable CO54     "Consultants, commercial labs, private R&D institutes:Other countries" ;
label variable CO61     "Universities or other ...:National" ;
label variable CO62     "Universities or other ...:EU/EFTA/EU-CC" ;
label variable CO63     "Universities or other ...:US" ;
label variable CO64     "Universities or other ...:Other countries" ;
label variable CO71     "Government or public research institutes:National" ;
label variable CO72     "Government or public research institutes:EU/EFTA/EU-CC" ;
label variable CO73     "Government or public research institutes:US" ;
label variable CO74     "Government or public research institutes:Other countries" ;
label variable PMOS     "Most important co-operation partner" ;
label variable ERANGE   "Increased range of goods or services" ;
label variable EMAR     "Increased market or market share" ;
label variable EQUA     "Improved quality in goods or services" ;
label variable EFLEX    "Improved production flexibility" ;
label variable ECAP     "Increased production capacity" ;
label variable ELBR     "Reduced labour costs per produced unit" ;
label variable EMAT     "Reduced materials and energy per produced unit" ;
label variable EENV     "Reduced environmental impact or health and safety aspects" ;
label variable ESTD     "Met regulations or standards" ;
label variable HCON     "Innovation activity abandoned at concept stage" ;
label variable HBEG     "Innovation activity abandoned after the activity/project begun" ;
label variable HDLAY    "Innovation activity seriously delayed" ;
label variable HFENT    "Hampering factor: Lack of funds within enterprises or ent. group" ;
label variable HFOUT    "Hampering factor : Lack of outside funds" ;
label variable HCOS     "Hampering factor : Innovation costs too high" ;
label variable HPER     "Hampering factor : Lack of qualified personnel" ;
label variable HTEC     "Hampering factor : Lack of information on technology" ;
label variable HINF     "Hampering factor : Lack of information on markets" ;
label variable HPAR     "Hampering factor : Difficulty in finding co-operation partners" ;
label variable HDOM     "Hampering factor : Market dominated by established enterprises" ;
label variable HDEM     "Hampering factor: Uncertain demand for innovative goods/services" ;
label variable HPRIOR   "No innovation activity due to prior innovations" ;
label variable HMAR     "No innovation activity due to no demand for innovations" ;
label variable PROPAT   "Applied for a patent" ;
label variable PRODSG   "Registered an industrial design" ;
label variable PROTM    "Register a trademark" ;
label variable PROCP    "Claimed copyright" ;
label variable ORGSYS   "Introduce improved knowledge management system" ;
label variable ORGSTR   "Introduce change to work organisation" ;
label variable ORGREL   "Introduce a change in relations with other firms..." ;
label variable MKTDES   "Introduce significant design/packaging changes" ;
label variable MKTMET   "Introduce significantly changed sales/distribution methods" ;
label variable EFORED   "Reduced time to respond to customers needs" ;
label variable EFORQU   "Improved quality of goods/services" ;
label variable EFORCO   "Reduced costs per unit output" ;
label variable EFORSA   "Improved employee satisfaction" ;
label variable NEWFRM   "Did the enterprise introduce a product new to the firm" ;
label variable STRB     "Stratum of the enterprise when sampling" ;
label variable STRA     "Stratum of the enterprise according to the questionnaire" ;


* Definition of category labels ;

label define LABELS_GROUP_1
1 "Mining and quarrying"
2 "Manufacture of food products, beverages and tobacco"
3 "Manufacture of textiles and textile products"
4 "Manufacture of leather and leather products"
5 "Manufacture of wood and wood products; manufacture of pulp, paper and paper products"
6 "Publishing, printing and reproduction of recorded media"
7 "Manufacture of coke, refined petroleum products and nuclear fuel, of chemicals, chemical products and man-made fibres"
8 "Manufacture of rubber and plastic products"
9 "Manufacture of other non-metallic mineral products"
10 "Manufacture of basic metals"
11 "Manufacture of fabricated metal products, except machinery and equipment"
12 "Manufacture of machinery and equipment n.e.c."
13 "Manufacture of electrical and optical equipment"
14 "Manufacture of transport equipment"
15 "Manufacturing n.e.c."
16 "Electricity, gas and water supply"
17 "Construction"
18 "Sale, maintenance and repair of motor vehicles and motorcycles; retail sale of automotive fuel"
19 "Wholesale trade and commission trade, except of motor vehicles and motorcycles"
20 "Retail trade, except of motor vehicles and motorcycles; repair of personal and household goods"
21 "Hotels and restaurants"
22 "Land transport; transport via pipelines; water transport, air transport"
23 "Supporting and auxiliary transport activities; activities of travel agencies"
24 "Post and telecommunications"
25 "Financial intermediation"
26 "Real estate activities"
27 "Renting of machinery and equipment without operator and of personal and household goods"
28 "Computer and related activities"
29 "Research and development; other business activities" ;

label define LABELS_GROUP_2
0 "No answer"
1 "Home country"
2 "EU, EFTA, CC"
3 "rest of the world"
4 "the enterprise does not belong to a group" ;

label define LABELS_GROUP_3
0 "Small (<50)"
1 "Medium (50-249)"
2 "Large (>=250)" 
3 ">=50, only for NACE 10, 19,20, 23, 50, 61, 64, 67, 70, 73, 742 and 743"
4 ">=0, only for NACE 30, 37, 62 and 71" ;

label define LABELS_GROUP_4
0 "No"
1 "Yes" ;

label define LABELS_GROUP_5
1 "Mainly by the enterprise or enterprise group"
2 "In cooperation with other enterprises or institutions"
3 "Mainly other enterprises or institutions" ;

label define LABELS_GROUP_6
1 "Continuously"
2 "Occasionally" ;

label define LABELS_GROUP_7
0 "Not used"
1 "Low"
2 "Med"
3 "High" ;

label define LABELS_GROUP_8
1 "Other enterprises within enterprise group"
2 "Suppliers of equipment, etc"
3 "Clients or customers"
4 "Competitors or other firms"
5 "Consultants, commercial labs, private R&D institutes"
6 "Universities or other ..."
7 "Government or public research institutes" ;

label define LABELS_GROUP_9
0 "Not relevant"
1 "Low"
2 "Med"
3 "High" ;

label define LABELS_GROUP_10
0 "Not experienced"
1 "Low"
2 "Med"
3 "High" ;



* Attachment of category labels to variables ;

label values NACE_PRO LABELS_GROUP_1 ;
label values C_HO     LABELS_GROUP_2 ;
label values SIZE02   LABELS_GROUP_3 ;
label values SIZE04   LABELS_GROUP_3 ;
label values GP       LABELS_GROUP_4 ;
label values MARLOC   LABELS_GROUP_4 ;
label values MARNAT   LABELS_GROUP_4 ;
label values MAREUR   LABELS_GROUP_4 ;
label values MAROTH   LABELS_GROUP_4 ;
label values INPDGD   LABELS_GROUP_4 ;
label values INPDSV   LABELS_GROUP_4 ;
label values NEWMKT   LABELS_GROUP_4 ;
label values INPSPD   LABELS_GROUP_4 ;
label values INPSLG   LABELS_GROUP_4 ;
label values INPSSU   LABELS_GROUP_4 ;
label values INONAB   LABELS_GROUP_4 ;
label values RRDIN    LABELS_GROUP_4 ;
label values RRDEX    LABELS_GROUP_4 ;
label values RMAC     LABELS_GROUP_4 ;
label values ROEK     LABELS_GROUP_4 ;
label values RTR      LABELS_GROUP_4 ;
label values RMAR     LABELS_GROUP_4 ;
label values RPRE     LABELS_GROUP_4 ;
label values FUNLOC   LABELS_GROUP_4 ;
label values FUNGMT   LABELS_GROUP_4 ;
label values FUNEU    LABELS_GROUP_4 ;
label values FUNRTD   LABELS_GROUP_4 ;
label values CO       LABELS_GROUP_4 ;
label values CO11     LABELS_GROUP_4 ;
label values CO12     LABELS_GROUP_4 ;
label values CO13     LABELS_GROUP_4 ;
label values CO14     LABELS_GROUP_4 ;
label values CO21     LABELS_GROUP_4 ;
label values CO22     LABELS_GROUP_4 ;
label values CO23     LABELS_GROUP_4 ;
label values CO24     LABELS_GROUP_4 ;
label values CO31     LABELS_GROUP_4 ;
label values CO32     LABELS_GROUP_4 ;
label values CO33     LABELS_GROUP_4 ;
label values CO34     LABELS_GROUP_4 ;
label values CO41     LABELS_GROUP_4 ;
label values CO42     LABELS_GROUP_4 ;
label values CO43     LABELS_GROUP_4 ;
label values CO44     LABELS_GROUP_4 ;
label values CO51     LABELS_GROUP_4 ;
label values CO52     LABELS_GROUP_4 ;
label values CO53     LABELS_GROUP_4 ;
label values CO54     LABELS_GROUP_4 ;
label values CO61     LABELS_GROUP_4 ;
label values CO62     LABELS_GROUP_4 ;
label values CO63     LABELS_GROUP_4 ;
label values CO64     LABELS_GROUP_4 ;
label values CO71     LABELS_GROUP_4 ;
label values CO72     LABELS_GROUP_4 ;
label values CO73     LABELS_GROUP_4 ;
label values CO74     LABELS_GROUP_4 ;
label values HCON     LABELS_GROUP_4 ;
label values HBEG     LABELS_GROUP_4 ;
label values HDLAY    LABELS_GROUP_4 ;
label values PROPAT   LABELS_GROUP_4 ;
label values PRODSG   LABELS_GROUP_4 ;
label values PROTM    LABELS_GROUP_4 ;
label values PROCP    LABELS_GROUP_4 ;
label values ORGSYS   LABELS_GROUP_4 ;
label values ORGSTR   LABELS_GROUP_4 ;
label values ORGREL   LABELS_GROUP_4 ;
label values MKTDES   LABELS_GROUP_4 ;
label values MKTMET   LABELS_GROUP_4 ;
label values INPDTW   LABELS_GROUP_5 ;
label values INPCSW   LABELS_GROUP_5 ;
label values RDENG    LABELS_GROUP_6 ;
label values SENTG    LABELS_GROUP_7 ;
label values SSUP     LABELS_GROUP_7 ;
label values SCLI     LABELS_GROUP_7 ;
label values SCOM     LABELS_GROUP_7 ;
label values SINS     LABELS_GROUP_7 ;
label values SUNI     LABELS_GROUP_7 ;
label values SGMT     LABELS_GROUP_7 ;
label values SCON     LABELS_GROUP_7 ;
label values SJOU     LABELS_GROUP_7 ;
label values SPRO     LABELS_GROUP_7 ;
label values PMOS     LABELS_GROUP_8 ;
label values ERANGE   LABELS_GROUP_9 ;
label values EMAR     LABELS_GROUP_9 ;
label values EQUA     LABELS_GROUP_9 ;
label values EFLEX    LABELS_GROUP_9 ;
label values ECAP     LABELS_GROUP_9 ;
label values ELBR     LABELS_GROUP_9 ;
label values EMAT     LABELS_GROUP_9 ;
label values EENV     LABELS_GROUP_9 ;
label values ESTD     LABELS_GROUP_9 ;
label values HFENT    LABELS_GROUP_10 ;
label values HFOUT    LABELS_GROUP_10 ;
label values HCOS     LABELS_GROUP_10 ;
label values HPER     LABELS_GROUP_10 ;
label values HTEC     LABELS_GROUP_10 ;
label values HINF     LABELS_GROUP_10 ;
label values HPAR     LABELS_GROUP_10 ;
label values HDOM     LABELS_GROUP_10 ;
label values HDEM     LABELS_GROUP_10 ;
label values HPRIOR   LABELS_GROUP_10 ;
label values HMAR     LABELS_GROUP_10 ;
label values EFORED   LABELS_GROUP_10 ;
label values EFORQU   LABELS_GROUP_10 ;
label values EFORCO   LABELS_GROUP_10 ;
label values EFORSA   LABELS_GROUP_10 ;

compress ;
save "`statapath'", replace ;

log close ;
set more on
#delimit cr
